pub struct CaseAttachmentService { /* private fields */ }Expand description
Implements a client for the Google Cloud Support API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = CaseAttachmentService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_attachments()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
A service to manage file attachments for Google Cloud support cases.
Configuration
To configure CaseAttachmentService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://cloudsupport.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
CaseAttachmentService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap CaseAttachmentService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl CaseAttachmentService
impl CaseAttachmentService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for CaseAttachmentService.
let client = CaseAttachmentService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: CaseAttachmentService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: CaseAttachmentService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_attachments(&self) -> ListAttachments
pub fn list_attachments(&self) -> ListAttachments
List all the attachments associated with a support case.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_support_v2::Result;
async fn sample(
client: &CaseAttachmentService, parent: &str
) -> Result<()> {
let mut list = client.list_attachments()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Trait Implementations
Sourceimpl Clone for CaseAttachmentService
impl Clone for CaseAttachmentService
Sourcefn clone(&self) -> CaseAttachmentService
fn clone(&self) -> CaseAttachmentService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more