#[non_exhaustive]pub enum Reason {
Unspecified,
ResolutionTime,
TechnicalExpertise,
BusinessImpact,
UnknownValue(UnknownValue),
}Expand description
An enum detailing the possible reasons a case may be escalated.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The escalation reason is in an unknown state or has not been specified.
ResolutionTime
The case is taking too long to resolve.
TechnicalExpertise
The support agent does not have the expertise required to successfully resolve the issue.
BusinessImpact
The issue is having a significant business impact.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Reason::value or Reason::name.
Implementations