#[non_exhaustive]pub struct ListSupportEventSubscriptionsRequest {
pub parent: String,
pub filter: String,
pub show_deleted: bool,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for ListSupportEventSubscriptions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The fully qualified name of the Cloud resource to list support event subscriptions under. Format: organizations/{organization_id}
filter: StringOptional. Filter expression based on AIP-160. Supported fields:
- pub_sub_topic
- state
Examples:
pub_sub_topic="projects/example-project/topics/example-topic"state=WORKINGpub_sub_topic="projects/example-project/topics/example-topic" AND state=WORKING
show_deleted: boolOptional. Whether to show deleted subscriptions. By default, deleted subscriptions are not returned.
page_size: i32Optional. The maximum number of support event subscriptions to return.
page_token: StringOptional. A token identifying the page of results to return. If unspecified, the first page is retrieved.
When paginating, all other parameters provided to
ListSupportEventSubscriptions must match the call that provided the page
token.
Implementations
Sourceimpl ListSupportEventSubscriptionsRequest
impl ListSupportEventSubscriptionsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_show_deleted<T: Into<bool>>(self, v: T) -> Self
pub fn set_show_deleted<T: Into<bool>>(self, v: T) -> Self
Sets the value of show_deleted.
Example
ⓘ
let x = ListSupportEventSubscriptionsRequest::new().set_show_deleted(true);Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListSupportEventSubscriptionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSupportEventSubscriptionsRequest
impl Clone for ListSupportEventSubscriptionsRequest
Sourcefn clone(&self) -> ListSupportEventSubscriptionsRequest
fn clone(&self) -> ListSupportEventSubscriptionsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListSupportEventSubscriptionsRequest
impl Default for ListSupportEventSubscriptionsRequest
Sourcefn default() -> ListSupportEventSubscriptionsRequest
fn default() -> ListSupportEventSubscriptionsRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListSupportEventSubscriptionsRequest