#[non_exhaustive]pub struct SupportEventSubscription {
pub name: String,
pub pub_sub_topic: String,
pub state: State,
pub failure_reason: FailureReason,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub purge_time: Option<Timestamp>,
/* private fields */
}Expand description
A support event subscription.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the support event subscription.
pub_sub_topic: StringRequired. The name of the Pub/Sub topic to publish notifications to. Format: projects/{project}/topics/{topic}
state: StateOutput only. The state of the subscription.
failure_reason: FailureReasonOutput only. Reason why subscription is failing. State of subscription must be FAILING in order for this to have a value.
create_time: Option<Timestamp>Output only. The time at which the subscription was created.
update_time: Option<Timestamp>Output only. The time at which the subscription was last updated.
delete_time: Option<Timestamp>Output only. The time at which the subscription was deleted.
purge_time: Option<Timestamp>Output only. The time at which the subscription will be purged.
Implementations
Sourceimpl SupportEventSubscription
impl SupportEventSubscription
Sourcepub fn set_pub_sub_topic<T: Into<String>>(self, v: T) -> Self
pub fn set_pub_sub_topic<T: Into<String>>(self, v: T) -> Self
Sets the value of pub_sub_topic.
Example
let x = SupportEventSubscription::new().set_pub_sub_topic("example");Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_support_v2::model::support_event_subscription::State;
let x0 = SupportEventSubscription::new().set_state(State::Working);
let x1 = SupportEventSubscription::new().set_state(State::Failing);
let x2 = SupportEventSubscription::new().set_state(State::Deleted);Sourcepub fn set_failure_reason<T: Into<FailureReason>>(self, v: T) -> Self
pub fn set_failure_reason<T: Into<FailureReason>>(self, v: T) -> Self
Sets the value of failure_reason.
Example
use google_cloud_support_v2::model::support_event_subscription::FailureReason;
let x0 = SupportEventSubscription::new().set_failure_reason(FailureReason::PermissionDenied);
let x1 = SupportEventSubscription::new().set_failure_reason(FailureReason::TopicNotFound);
let x2 = SupportEventSubscription::new().set_failure_reason(FailureReason::Other);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = SupportEventSubscription::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = SupportEventSubscription::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = SupportEventSubscription::new().set_or_clear_delete_time(None::<Timestamp>);Sourcepub fn set_purge_time<T>(self, v: T) -> Self
pub fn set_purge_time<T>(self, v: T) -> Self
Sets the value of purge_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_purge_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_purge_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_purge_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of purge_time.
Example
use wkt::Timestamp;
let x = SupportEventSubscription::new().set_or_clear_purge_time(Some(Timestamp::default()/* use setters */));
let x = SupportEventSubscription::new().set_or_clear_purge_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for SupportEventSubscription
impl Clone for SupportEventSubscription
Sourcefn clone(&self) -> SupportEventSubscription
fn clone(&self) -> SupportEventSubscription
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more