#[non_exhaustive]pub enum FailureReason {
Unspecified,
PermissionDenied,
TopicNotFound,
Other,
UnknownValue(UnknownValue),
}Expand description
The reason why the subscription is failing.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified failure reason.
PermissionDenied
The service account (i.e. cloud-support-apievents@system.gserviceaccount.com) lacks the permission to publish to the customer’s Pub/Sub topic.
TopicNotFound
The specified Pub/Sub topic does not exist.
Other
Message failed to publish due to a system-side error.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using FailureReason::value or FailureReason::name.
Implementations