Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
organization_id: &str,
case_id: &str,
) -> anyhow::Result<()> {
let client = CaseAttachmentService::builder().build().await?;
let mut list = client.list_attachments()
.set_parent(format!("organizations/{organization_id}/cases/{case_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Concrete implementations of this client library traits.
Structs
- Case
Attachment Service - Implements a client for the Google Cloud Support API.
- Case
Service - Implements a client for the Google Cloud Support API.
- Comment
Service - Implements a client for the Google Cloud Support API.