Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = CaseAttachmentService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_attachments()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Concrete implementations of this client library traits.
Structs
- Case
Attachment Service - Implements a client for the Google Cloud Support API.
- Case
Service - Implements a client for the Google Cloud Support API.
- Comment
Service - Implements a client for the Google Cloud Support API.