#[non_exhaustive]pub struct SearchCasesRequest {
pub parent: String,
pub query: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
The request message for the SearchCases endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe name of the parent resource to search for cases under.
query: StringAn expression used to filter cases.
Expressions use the following fields separated by AND and specified with
=:
state: Can beOPENorCLOSED.priority: Can beP0,P1,P2,P3, orP4. You can specify multiple values for priority using theORoperator. For example,priority=P1 OR priority=P2.creator.email: The email address of the case creator.
To search across displayName, description, and comments, use a global
restriction with no keyword or operator. For example, "my search".
To search only cases updated after a certain date, use update_time
restricted with that particular date, time, and timezone in ISO datetime
format. For example, update_time>"2020-01-01T00:00:00-05:00".
update_time only supports the greater than operator (>).
If you are using the v2 version of the API, you must specify the case
parent in the parent field. If you provide an empty query, all cases
under the parent resource will be returned.
If you are using the v2beta version of the API, you must specify the case
parent in the query field using one of the two fields below, which are
only available for v2beta. The parent field will be ignored.
organization: An organization name in the formorganizations/<organization_id>.project: A project name in the formprojects/<project_id>.
Examples:
For v2:
state=CLOSEDstate=OPEN AND creator.email="tester@example.com"state=OPEN AND (priority=P0 OR priority=P1)update_time>"2020-01-01T00:00:00-05:00"
For v2beta:
organization="organizations/123456789"project="projects/my-project-id"project="projects/123456789"organization="organizations/123456789" AND state=CLOSEDproject="projects/my-project-id" AND creator.email="tester@example.com"project="projects/my-project-id" AND (priority=P0 OR priority=P1)
page_size: i32The maximum number of cases fetched with each request. The default page size is 10.
page_token: StringA token identifying the page of results to return. If unspecified, the first page is retrieved.
Implementations
Sourceimpl SearchCasesRequest
impl SearchCasesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = SearchCasesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for SearchCasesRequest
impl Clone for SearchCasesRequest
Sourcefn clone(&self) -> SearchCasesRequest
fn clone(&self) -> SearchCasesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more