pub trait SupportEventSubscriptionService:
Debug
+ Send
+ Sync {
// Provided methods
fn create_support_event_subscription(
&self,
_req: CreateSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send { ... }
fn get_support_event_subscription(
&self,
_req: GetSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send { ... }
fn list_support_event_subscriptions(
&self,
_req: ListSupportEventSubscriptionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSupportEventSubscriptionsResponse>>> + Send { ... }
fn update_support_event_subscription(
&self,
_req: UpdateSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send { ... }
fn delete_support_event_subscription(
&self,
_req: DeleteSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send { ... }
fn undelete_support_event_subscription(
&self,
_req: UndeleteSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::SupportEventSubscriptionService.
Application developers may need to implement this trait to mock
client::SupportEventSubscriptionService. In other use-cases, application developers only
use client::SupportEventSubscriptionService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn create_support_event_subscription(
&self,
_req: CreateSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
fn create_support_event_subscription( &self, _req: CreateSupportEventSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
Sourcefn get_support_event_subscription(
&self,
_req: GetSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
fn get_support_event_subscription( &self, _req: GetSupportEventSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
Sourcefn list_support_event_subscriptions(
&self,
_req: ListSupportEventSubscriptionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListSupportEventSubscriptionsResponse>>> + Send
fn list_support_event_subscriptions( &self, _req: ListSupportEventSubscriptionsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListSupportEventSubscriptionsResponse>>> + Send
Sourcefn update_support_event_subscription(
&self,
_req: UpdateSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
fn update_support_event_subscription( &self, _req: UpdateSupportEventSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
Sourcefn delete_support_event_subscription(
&self,
_req: DeleteSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
fn delete_support_event_subscription( &self, _req: DeleteSupportEventSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
Sourcefn undelete_support_event_subscription(
&self,
_req: UndeleteSupportEventSubscriptionRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
fn undelete_support_event_subscription( &self, _req: UndeleteSupportEventSubscriptionRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SupportEventSubscription>>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".